﻿ 
////////////////////////////////////Carousel
(function ($) {

    var methods = {
        getItemWidth: function () {
            return getObjDimensions(this.find("li").first()).width;
        },
        scrollCarouselRegion: function (carousel, index) {
            var currentView = parseInt($(carousel).attr("data-viewindex"));

            if (index == currentView) {
                return false;
            }
            var totalViews = parseInt($(carousel).attr("data-viewcount"));
            var viewPortWidth = $(carousel).parent().width();
            var itemMargin = methods.getObjDimensions($(carousel).find("li").first()).marginRight;

            if (index == 'prev') {
                index = parseInt(currentView - 1);
            }
            if (index == 'next') {
                index = parseInt(currentView + 1);
            }

            if (index == 0) {
                $(carousel).closest(".NextCarouselWrapper").find("li.NextCarouselPrevious").addClass("disabled");

            }

            if (index > 0) {
                $(carousel).closest(".NextCarouselWrapper").find("li.NextCarouselPrevious").removeClass("disabled");
            }


            if (index == totalViews - 1) {
                $(carousel).closest(".NextCarouselWrapper").find("li.NextCarouselNext").addClass("disabled");

            }

            if (index < totalViews - 1) {
                $(carousel).closest(".NextCarouselWrapper").find("li.NextCarouselNext").removeClass("disabled");
            }


            if (index < 0) { return false; }
            if (index == totalViews) { return false; }
            var diff = index - currentView;
            var distance = (diff * viewPortWidth) + (diff * itemMargin);

            //console.log(distance);
            $(carousel).animate({
                left: '-=' + distance
            }, 500, function () {
            });

            $(carousel).attr("data-viewindex", index);

            var curLinkIndex = -1;
            var navList = $(carousel).parent().parent().find(".NextNavWrapper").find("ul");
            $(navList).find("li").each(function () {
                $(this).removeClass("NextCarouselLinkActive");
                if (curLinkIndex == index) {
                    $(this).addClass("NextCarouselLinkActive");
                }
                curLinkIndex++;
            });

            return false;
        },
        getIntFromPixelValue: function (pixelValue) {
            if (!pixelValue) { return 0; }
            pixelValue = pixelValue.replace('px', '');
            return parseInt(pixelValue);
        },
        getObjDimensions: function (obj) {
            //width
            var Width = methods.getIntFromPixelValue($(obj).css("width"));
            var PaddingLeft = methods.getIntFromPixelValue($(obj).css("padding-left"));
            var PaddingRight = methods.getIntFromPixelValue($(obj).css("padding-left"));
            var marginLeft = methods.getIntFromPixelValue($(obj).css("margin-left"));
            var marginRight = methods.getIntFromPixelValue($(obj).css("margin-right"));
            var borderLeft = methods.getIntFromPixelValue($(obj).css("border-left-width"));
            var borderRight = methods.getIntFromPixelValue($(obj).css("border-right-width"));
            var totalWidth = Width + PaddingLeft + PaddingRight + marginLeft + marginRight + borderLeft + borderRight;

            //height
            var Height = methods.getIntFromPixelValue($(obj).css("height"));
            var PaddingTop = methods.getIntFromPixelValue($(obj).css("padding-top"));
            var PaddingBottom = methods.getIntFromPixelValue($(obj).css("padding-bottom"));
            var marginTop = methods.getIntFromPixelValue($(obj).css("margin-top"));
            var marginBottom = methods.getIntFromPixelValue($(obj).css("margin-bottom"));
            var borderTop = methods.getIntFromPixelValue($(obj).css("border-top-width"));
            var borderBottom = methods.getIntFromPixelValue($(obj).css("border-bottom-width"));
            var totalHeight = Height + PaddingTop + PaddingBottom + marginTop + marginBottom + borderTop + borderBottom;

            var dimension = { "height": totalHeight, "width": totalWidth, "marginLeft": marginLeft, "marginRight": marginRight };

            return dimension;
        }
    };


    $.fn.NextCarousel = function (config) {

        var settings = $.extend({
            'VisibleItems': 4,
            'ItemsToScroll': 5,
            'CompactNav': true,
            'LeftRightNav': false
        }, config);

        var NextCarousel = this;

        //Remove any existing carousel nav
        this.find(".NextNavWrapper").remove();

        $(NextCarousel).addClass("NextCarousel");
        var clippingDiv = $("<div />");
        $(clippingDiv).addClass("NextCarouselClippingRegion");
        this.wrap(clippingDiv);

        var wrappingDiv = $("<div />");
        $(wrappingDiv).addClass("NextCarouselWrapper");
        this.parent().wrap(wrappingDiv);

        var listItemDimensions = methods.getObjDimensions(this.find("li").first());
        var clippingRegionWidth = (listItemDimensions.width * settings.VisibleItems) - listItemDimensions.marginRight;
        var itemCount = this.find("li").length;

        var listWidth = listItemDimensions.width * itemCount;
        var viewCount = Math.ceil(itemCount / settings.VisibleItems);
        //console.log(listWidth + " " + listItemDimensions.marginRight + " " + clippingRegionWidth);
        this.width(listWidth);

        this.attr("data-viewindex", 0);
        this.attr("data-viewcount", viewCount);

        $(".NextCarouselWrapper").width(clippingRegionWidth);
        $(".NextCarouselClippingRegion").width(clippingRegionWidth);

        //Compact nav
        if (settings.CompactNav && itemCount > settings.VisibleItems) {
            var navContainer = $("<div />");
            $(navContainer).addClass("NextNavWrapper");
            var navList = $("<ul />");
            var prevLinkItem = $("<li />");
            $(prevLinkItem).addClass("NextCarouselPrevious");
            $(prevLinkItem).addClass("disabled");
            var prevLink = $("<a  href=\"#\">Previous</a>");
            $(prevLink).click(function () {
                methods.scrollCarouselRegion(NextCarousel, 'prev');
                return false;
            });
            $(prevLinkItem).append(prevLink);
            $(navList).append(prevLinkItem);



            for (i = 0; i < viewCount; i++) {

                var navItem = $("<li />");
                if (i == 0) {
                    $(navItem).addClass("NextCarouselLinkActive");
                }
                var navLink = $("<a href=\"#\" >" + i + "</a>");
                $(navLink).click(function () {
                    methods.scrollCarouselRegion(NextCarousel, $(this).text());
                    return false;
                });
                $(navItem).append(navLink);
                $(navList).append(navItem);
            }

            var nextLinkItem = $("<li />");
            $(nextLinkItem).addClass("NextCarouselNext");

            var nextLink = $("<a href=\"#\">Next</a>");
            $(nextLink).click(function () {
                methods.scrollCarouselRegion(NextCarousel, 'next');
                return false;
            });

            $(nextLinkItem).append(nextLink);
            $(navList).append(nextLinkItem);

            $(navContainer).append(navList);
            this.parent().after(navContainer);

            var ulWidth = 0;
            $(navList).find("li").each(function () {
                ulWidth += 16;
            })
            $(navList).width(ulWidth);
            $(navContainer).width(ulWidth);

        }


        if (settings.LeftRightNav && itemCount > settings.VisibleItems) {
            var prevLinkLarge = $("<a class=\"NextCarouselLeft\" href=\"#\" >Previous</a>");
            $(prevLinkLarge).click(function () {
                methods.scrollCarouselRegion(NextCarousel, 'prev');
                return false;
            });
            var nextLinkLarge = $("<a class=\"NextCarouselRight\" href=\"#\" >Next</a>");
            $(nextLinkLarge).click(function () {
                methods.scrollCarouselRegion(NextCarousel, 'next');
                return false;
            });
            this.parent().before(prevLinkLarge);
            this.parent().after(nextLinkLarge);
        }

        //console.log("classes added");

    };
})(jQuery);

////////////////////////////////////SlideWindow
(function ($) {
    var methods = {

        init: function (options) {
            this.addClass("NextSlideWindow");
            var NextSlideWindow = this;
            var heading = this.children().first();
            var content = $(heading).next();
            var contentHeight = $(content).height();
            var openButton = $("<a href=\"#\" class=\"btnOpen\" >Open</a>");
            var closeButton = $("<a href=\"#\" class=\"btnClose\" >Close</a>");

            //Open///////////
            $(openButton).click(function () {

                var targetHeight;

                if($(NextSlideWindow).hasClass("ReviewContainer")) {
                    var reviewContent =  $(".reviewContent");
                    var containerHeight = $(reviewContent).height();
                    if (containerHeight == 0 ) {
                       var itemCount =  $(reviewContent).find("ul li.reviewBlock").size();
                       containerHeight = itemCount * 265;
                    }
                    targetHeight = containerHeight + 17;
                } 
                else if($(NextSlideWindow).hasClass("Categories")) {
                    targetHeight = 340;
                }
                else {
                    targetHeight = 170;
                }
                
                $(NextSlideWindow).animate({
                    height: "+=" + targetHeight
                }, 500, function(){
                    $(NextSlideWindow).removeAttr("style");
                });

              
               if(!$(".ProductPage").length){
                    $("html,body").animate({scrollTop: $(NextSlideWindow).offset().top - $(".PageHeader").height()}, "easeOutCubic");
                }

                $(closeButton).show();
                $(openButton).hide();

                $(heading).next().fadeIn(300);

                return false;
            });

            //Close///////////
            $(closeButton).click(function () {
              //  var targetHeight = $(this).parent().next().height();

                $(NextSlideWindow).animate({
                    height: 54
                }, 500);

                $(closeButton).hide();
                $(openButton).show();

                $(heading).next().fadeOut(300);
                if ($(NextSlideWindow).hasClass("ReviewContainer")) {
                    $(".reviewPagination").fadeOut(300);
                }
                return false;
            });



            $(heading).prepend(closeButton);
            $(heading).prepend(openButton);

            $(openButton).hide();
        },

        Open: function(){

                var targetHeight;
                var animate = true;
                if(this.hasClass("ReviewContainer")) {
                animate = false;
                this.removeAttr("style");
//                    var reviewContent =  $(".reviewContent");
//                    var containerHeight = $(reviewContent).height();
//                    if (containerHeight == 0 ) {
//                       var itemCount =  $(reviewContent).find("ul li.reviewBlock").size();
//                       containerHeight = itemCount * 265;
//                    }
//                    targetHeight = containerHeight + 17;
                } 
                else if(this.hasClass("Categories")) {
                    targetHeight = 340;
                }
                else {
                    targetHeight = 170;
                }
                


                if(animate){
                    this.animate({
                        height: "+=" + targetHeight
                    }, 500, function(){
                    
                    });
                }

                var heading = this.children().first();

                this.find("a.btnOpen").hide();
                this.find("a.btnClose").show();

                $(heading).next().fadeIn(300);

        },
        Close: function(){

          this.animate({
                    height: 54
                }, 500);

                var heading = this.children().first();

                this.find("a.btnOpen").show();
                this.find("a.btnClose").hide();

                $(heading).next().fadeOut(300);

        },
        DataBind: function (data, suppressAnimation) {

            var heading = this.children().first();
            var content = $(heading).next();
           // var currentContentHeight = $(content).height();
            $(content).html(data);

        

            if(!suppressAnimation){

            var openButton = $(this).find("a.btnOpen");
       
                if($(openButton).css('display') == 'block' || $(openButton).css('display') == 'inline')
                {
                   $(openButton).click();
                }else{
                
                    var targetHeight = $(".reviewContent").height() + 71;
                    $(this).animate({
                        height: targetHeight
                    }, 500);
                }
            }else{
                $(this).find("a.btnClose").click();
           
            }


//            var contentHeight = $(content).height();
//            var targetHeight = currentContentHeight - contentHeight;
//            var itemsContainerHeight = $('.itemsContainer').height();
//            var pageBottomWrapperHeight = $('.pageBottomWrapper').height();
//            var totalHeight = itemsContainerHeight + pageBottomWrapperHeight;


            // $('#ContentArea').css('min-height', totalHeight + 70);
            //          
            //          $("#ContentArea").animate({
            //               height: "+=" + targetHeight
            //          },500);

        }

    };


    $.fn.NextSlideWindow = function (method) {

        if (methods[method]) {
            return methods[method].apply(this, Array.prototype.slice.call(arguments, 1));
        } else if (typeof method === 'object' || !method) {
            return methods.init.apply(this, arguments);
        } else {
            $.error('Method ' + method + ' does not exist on jQuery.validateControl');
        }
    };

})(jQuery);


/////////////////////////////////////Helper PopUp
(function ($) {


    var methods = {


        //          showDialogue: function(src, settings) {

        //            var title = $(src).attr("data-name");
        //            var description = $(src).attr("data-description");

        //            var dialougue = $("<div class=\"NextHelperPopUp\" />");
        //            var heading = $("<h3 />");
        //            var para = $("<p />");
        //            $(heading).text(title);
        //            $(para).text(description);

        //            if ($(src).attr("data-description-id"))
        //                $(para).html($('#' + $(src).attr("data-description-id")).html());

        //            $(dialougue).append(heading);
        //            $(dialougue).append(para);

        //            //Apend dialogue to element
        //            if($(settings.target).length > 0){
        //             $(target).append(dialougue);
        //            }else{
        //            $(src).after(dialougue);
        //            }
        //           
        //           if(settings.width > 0){
        //           $(dialougue).width(settings.width);
        //           }

        //            var dialogueHeight = $(dialougue).height();
        //            var srcHeight = $(src).height();
        //            var srcWidth = $(src).width();
        //            var srcOffset = $(src).offset();

        //            var animateValue = "-=15";

        //            switch(settings.align)
        //                    {
        //                    case 'top':
        //                             var offsetTop = srcOffset.top - (dialogueHeight + (srcHeight * 2));
        //                             $(dialougue).offset({ left: srcOffset.left - 40, top: offsetTop });
        //                               $(dialougue).addClass("popTop");
        //                    break;
        //                    case 'right': 
        //                            var offsetTop = srcOffset.top - (dialogueHeight/3);
        //                            var offsetLeft = srcOffset.left + srcWidth + 35;
        //                            $(dialougue).offset({ left: offsetLeft, top: offsetTop });
        //                            $(dialougue).addClass("popRight");
        //                    break;
        //                    case 'left':
        //                            var offsetTop = srcOffset.top - (27);
        //                            var offsetLeft = srcOffset.left - $(dialougue).width() - 45;
        //                            $(dialougue).offset({ left: offsetLeft, top: offsetTop });
        //                            $(dialougue).addClass("popLeft");
        //                            animateValue = "+=15";
        //                    break;

        //            }

        //            $(dialougue).hide();

        //            //Animate dialogue into view
        //            $(dialougue).animate({
        //            opacity: 'toggle',
        //            left: animateValue
        //            }, 200
        //            );

        //            if(settings.autoClose){
        //            $(src).mouseleave(function () {
        //                $(dialougue).animate({
        //                    opacity: 'toggle',
        //                    left: animateValue
        //                }, 200, function () { $(this).remove(); }
        //            ); });
        //            }
        //          
        //        }

    };

    $.fn.NextHelperPopUp = function (config) {

        var settings = $.extend({
            'target': '',
            'align': 'right',
            'autoClose': true,
            'width': 0
        }, config);

    

        this.mouseover(function () {
            var $this = this;
            $($this).addClass("popTargetOver");

            if(settings.delay){
                
                setTimeout(function(){
                    if($($this).hasClass("popTargetOver")){
                        showDialoguePopUp($this, settings);
                    }
                
                },settings.delay);

            }else{
                 showDialoguePopUp($this, settings);
            }
        });

        this.mouseout(function(){
          var $this = this;
           $($this).removeClass("popTargetOver");
        });


    };
})(jQuery);


function hideDialoguePopUp(src) {
    var animateValue = "-=15";
    var dialougue = $(src).next(".NextHelperPopUp");

    if ($(dialougue).length) { 
      $(dialougue).animate({
        opacity: 'toggle',
        left: animateValue
    }, 200, function () { $(dialougue).remove(); });
    }

}



function showDialoguePopUp(src, settings) {

    //Don't add dialogue if it has already been added
    if ($(src).next().hasClass("NextHelperPopUp")) {
        return false;
    }

    var title = $(src).attr("data-name");
    var description = $(src).attr("data-description");
    var icon = $(src).attr("data-icon");

    if (title == null) {
        title = settings.title;
    }

    if (description == null) {
        description = settings.description;
    }

    if (icon == null) {
        icon = settings.icon;
    }


    var dialougue = $("<div class=\"NextHelperPopUp\" />");
    if (settings.errorMessage) {
        $(dialougue).addClass("errorMessage");
    }

    if (settings.customCSS) {
        $(dialougue).attr("style", settings.customCSS);
    }


    if (icon != null) {
        var img = $("<img />");
        $(img).attr("src", icon).addClass("popIcon");
        $(dialougue).append(img);
    }


    var heading = $("<h3 />");
    var para = $("<p />");

    if (title != null) {
        $(heading).html(title);
    }

    $(para).html(description);


    if (settings.color) {
        $(para).css("color", settings.color);
    }

    if ($(src).attr("data-description-id"))
        $(para).html($('#' + $(src).attr("data-description-id")).html());
    if (title != null) {
        $(dialougue).append(heading);
    }
    $(dialougue).append(para);

    //Apend dialogue to element
    if ($(settings.target).length > 0) {
        $(target).append(dialougue);
    } else {
        $(src).after(dialougue);
    }

    if (settings.width > 0) {
        $(dialougue).width(settings.width);
    }

    var dialogueHeight = $(dialougue).height();

    if (icon != null) {
        $(img).css("margin-bottom", dialogueHeight - $(img).height());
    }

    var srcHeight = $(src).height();
    var srcWidth = $(src).width();
    var srcOffset = $(src).offset();

    var animateValue = "-=15";
    var dialogueWidth = $(dialougue).width();

    var customLeftMargin = 0;

    if (settings.marginLeft) {
        customLeftMargin = settings.marginLeft;
    }

    var customMarginTop = 0;
    if (settings.marginTop) {
        customMarginTop = settings.marginTop;
    }



    switch (settings.align) {
        case 'top':
            var offsetTop = srcOffset.top - (dialogueHeight + (srcHeight * 2));
            $(dialougue).offset({ left: srcOffset.left - 40, top: offsetTop + customMarginTop });
            $(dialougue).addClass("popTop");
            break;
        case 'right':
            var offsetTop = srcOffset.top - (dialogueHeight / 2);
            if (settings.errorMessage) {
                offsetTop = srcOffset.top - srcHeight;
            }
            var offsetLeft = srcOffset.left + srcWidth + 35;
            $(dialougue).offset({ left: offsetLeft + customLeftMargin, top: offsetTop + customMarginTop });
            $(dialougue).addClass("popRight");
            break;
        case 'left':
            var offsetTop = srcOffset.top - (27);
            var offsetLeft = srcOffset.left - $(dialougue).width() - 45;
            $(dialougue).offset({ left: offsetLeft + customLeftMargin, top: offsetTop + customMarginTop });
            $(dialougue).addClass("popLeft");
            animateValue = "+=15";
            break;
        case 'bottom':
            var offsetTop = srcOffset.top + srcHeight + 11;
            var offsetLeft = srcOffset.left - (dialogueWidth/2);
            $(dialougue).offset({ left: offsetLeft + customLeftMargin, top: offsetTop + customMarginTop });
            $(dialougue).addClass("popBottom");
            animateValue = "+=15";
            break;


    }

    $(dialougue).hide();

    //Animate dialogue into view
    $(dialougue).animate({
        opacity: 'toggle',
        left: animateValue
    }, 200 );

    if (settings.autoClose) {
        $(src).mouseleave(function () {
            $(dialougue).animate({
                opacity: 'toggle',
                left: animateValue
            }, 200, function () { $(this).remove(); }
            );
        });
    }



    if (settings.closeOnDialogueOut) {
        $(dialougue).mouseleave(function () {
            $(dialougue).animate({
                opacity: 'toggle',
                left: animateValue
            }, 200, function () { $(this).remove(); }
            );
        });
    }

  

}






