﻿(function ($) {

    var methods = {
        init: function (options) {
            switch (this[0].type) {
                //input of type text                                                                     
                case "text":
                    //Set events to fire validation
                    if (this.hasClass("requiredDate")) {
                        this.blur(function () { methods.requiredDate(this); });
                        this.keyup(function () { methods.requiredDate(this); });
                        this.change(function () { methods.requiredDate(this); });
                    }
                    else if (this.hasClass("required")) {
                        this.blur(function () { methods.requiredTextBox(this); });
                        this.keyup(function () { methods.requiredTextBox(this); });

                        if (this.hasClass("requiredEmail")) {
                            this.blur(function () { methods.requiredEmail(this); });
                            this.keyup(function () { methods.requiredEmail(this); });
                        }
                    }

                    //Create validation result icon and bind to control
                    var resultIcon = $("<div />");
                    $(resultIcon).addClass("resultIcon");
                    this.after(resultIcon);
                    //Text box text/content can't run under the icon - add padding and then resize to original size so we don't interfere with the design
                    this.css("padding-right", $(resultIcon).width() + parseInt(this.css("padding-right").replace("px", "")));
                    this.width(this.width() - $(resultIcon).width());
                    //If tooltip is required, bind this to the result icon
                    if (this.attr("data-error").length > 0) {
                        $(resultIcon).attr("data-description", this.attr("data-error"));
                        var popupAlign = "right";
                        if ((typeof options !== 'undefined') && (typeof options.popAlign !== 'undefined'))
                            popupAlign = options.popAlign;
                        $(resultIcon).NextHelperPopUp({ 'width': 150, 'align': popupAlign });
                    }

                    break;
                case "select-one":
                    //this.click(function () { alert("ff"); });
                    break;

                case "textarea":
                    // this.click(function () { alert("ss"); });
                    break;
            }

            return this;

        },

        showValidationResult: function (target, pass) {

            if (pass) {
                $(target).next(".resultIcon").addClass("valid");
                $(target).next(".resultIcon").removeClass("error");
            } else {

                $(target).next(".resultIcon").removeClass("valid");
                $(target).next(".resultIcon").addClass("error");
            }

        },
        displayErrorDialogue: function (control) {
            var settings = {
                'target': '',
                'align': 'right',
                'autoClose': false,
                'width': 120,
                'errorMessage': true
            };

            showDialoguePopUp(control, settings);

            setTimeout(function () { hideDialoguePopUp(control); }, 2000);

            $(control).change(function () {
                methods.requiredDropDown(this);
            });
        },
        hideErrorDialogue: function (control) {
            hideDialoguePopUp(control);
        },
        requiredTextBox: function (textBox) {

            //Make sure default value has changed
            if ($(textBox).val().length > 0 && $(textBox).attr("data-default").length > 0) {
                if ($(textBox).val() == $(textBox).attr("data-default")) {
                    methods.showValidationResult(textBox, false);
                    return false;
                }
            }

            //Basic required textbox validator
            if ($(textBox).val().length == 0) {
                methods.showValidationResult(textBox, false);

                //                if ($(textBox).attr("data-error").length > 0) {
                //                    $(textBox).next(".resultIcon").attr("data-description", $(textBox).attr("data-error"));
                //                }

                return false;
            } else {
                methods.showValidationResult(textBox, true);
                //                if ($(textBox).attr("data-valid").length > 0) {
                //                    $(textBox).next(".resultIcon").attr("data-description", $(textBox).attr("data-valid"));
                //                }
                return true;
            };

        },
        requiredEmail: function (textBox) {
            var tbVal = $(textBox).val();
            var emailregex = new RegExp('^[A-Za-z0-9\-\_\.]+@([A-Za-z0-9\-\_\.]+\.)+[A-Za-z\.]+$');

            if (tbVal.match(emailregex)) {
                methods.showValidationResult(textBox, true);
                return true;
            } else {
                methods.showValidationResult(textBox, false);
                return false;
            }

        },
        requiredDropDown: function (dropDown) {
            var ddlVal = $(dropDown).val();
            if (ddlVal == "" || ddlVal == null) {
                methods.displayErrorDialogue(dropDown);
                $(dropDown).addClass("error");
                return false;
            } else {
                $(dropDown).removeClass("error");
                methods.hideErrorDialogue(dropDown);
                return true;
            }
        },
        requiredDate: function (datePicker) {
            var dpVal = $(datePicker).val();

            var dateRegEx = new RegExp(/\b\d{1,2}[\/-]\d{1,2}[\/-]\d{4}\b/);

            if (dpVal.match(dateRegEx)) {

                var isValid = true;

                if (isValid && $(datePicker).data("validation-maxdate")) {
                    isValid = this.requiredDateRange(datePicker, true);
                }

                if (isValid && $(datePicker).data("validation-mindate")) {
                    isValid = this.requiredDateRange(datePicker, false);
                }

                if (isValid) {
                    methods.showValidationResult(datePicker, true);
                }

                return isValid;
            } else {
                methods.showValidationResult(datePicker, false);
                return false;
            }
        },
        //"requiredDateRange" Function validates whether a date value is greater/less than a limit rule supplied in a data-* (validation-maxdate / validation-mindate)
        //Current rules:
        //  "today" - The current date will be the min/max limit
        //  "(+/-)(int)d - The limit will be plus/minus x number of days compared to today. E.g "+60d" will be 60 days into the future.
        //-------
        //isMax = If true, validation is for the maximum limit. If false, validation is for the minimum limit.
        requiredDateRange: function (textbox, isMax) {
            var $textbox = $(textbox);

            var dateLimitRule;
            if (isMax) {
                dateLimitRule = $textbox.data("validation-maxdate");
            }
            else {
                dateLimitRule = $textbox.data("validation-mindate");
            }

            if (dateLimitRule) {

                var dmy = $textbox.val().split("index.html");
                var selectedDate = new Date(parseInt(dmy[2], 10), parseInt(dmy[1], 10) - 1, parseInt(dmy[0], 10));

                //Check date is valid.
                if (selectedDate != "Invalid Date") {

                    var dt = new Date();

                    var dateLimit = new Date(dt.getFullYear(), dt.getMonth(), dt.getDate());

                    //Regex rule
                    var regexRule = new RegExp(/^(\+|\-)([0-9]*)(d)$/) //(xx)d e.g +60d or -45d

                    if (dateLimitRule == "today") {
                        dateLimit = new Date(dt.getFullYear(), dt.getMonth(), dt.getDate());
                    }
                    else if (regexRule.test(dateLimitRule)) {

                        var plusMinus = dateLimitRule.match(regexRule)[1]

                        switch (dateLimitRule.match(regexRule)[3]) {
                            case "d": //days
                                var days = dateLimitRule.match(regexRule)[2]; //returns integer part of regex rule

                                switch (plusMinus) {
                                    case "+":
                                        dateLimit.setDate((new Date()).getDate() + (parseInt(days)));
                                        break;
                                    case "-":
                                        dateLimit.setDate((new Date()).getDate() - (parseInt(days)));
                                        break;
                                }


                                break;
                        }

                    }

                    if (isMax) {
                        //check whether dateLimit is less than selectedDate
                        //If so, return false, display validation error
                        if (dateLimit.getTime() < selectedDate.getTime()) {
                            methods.showValidationResult(textbox, false);
                            return false;
                        }

                    }
                    else {
                        //check whether dateLimit is greater than selectedDate
                        //If so, return false, display validation error
                        if (dateLimit.getTime() > selectedDate.getTime()) {
                            methods.showValidationResult(textbox, false);
                            return false;
                        }
                    }


                }

            }

            return true;

        },
        //This allows us to call the 'validate' method from outside the plugin e.g. from a form submit
        validate: function () {
            if (this[0].type == "text") {

                if (this.hasClass("requiredEmail")) {
                    return methods.requiredEmail(this);
                }

                if (this.hasClass("requiredDate")) {
                    return methods.requiredDate(this);
                }

                return methods.requiredTextBox(this);
            }

            if (this[0].type == "select-one") {
                return methods.requiredDropDown(this);
            }

            //Didn't hit any fields
            return true;
        }
    };

    $.fn.validateControl = function (method) {

        if (methods[method]) {
            return methods[method].apply(this, Array.prototype.slice.call(arguments, 1));
        } else if (typeof method === 'object' || !method) {
            return methods.init.apply(this, arguments);
        } else {
            $.error('Method ' + method + ' does not exist on jQuery.validateControl');
        }
    };

})(jQuery);


$(document).ready(function () {
//    $(".required").each(function () {
//        $(this).validateControl();
//    });

    //$(".required").validateControl();        
});



